|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r79452 - in trunk: boost/config boost/config/compiler boost/config/stdlib libs/config/doc libs/config/doc/html libs/config/doc/html/boost_config libs/config/test libs/config/test/all
From: marshall_at_[hidden]
Date: 2012-07-12 09:57:06
Author: marshall
Date: 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
New Revision: 79452
URL: http://svn.boost.org/trac/boost/changeset/79452
Log:
Deprecated BOOST_NO_NUMERIC_LIMITS_LOWEST; use BOOST_NO_CXX11_NUMERIC_LIMITS instead
Added:
trunk/libs/config/test/boost_no_cxx11_numeric_limits.ipp
- copied, changed from r79449, /trunk/libs/config/test/boost_no_limits_lowest.ipp
trunk/libs/config/test/no_cxx11_numeric_limits_fail.cpp
- copied, changed from r79449, /trunk/libs/config/test/no_limits_lowest_fail.cpp
trunk/libs/config/test/no_cxx11_numeric_limits_pass.cpp
- copied, changed from r79449, /trunk/libs/config/test/no_limits_lowest_pass.cpp
Removed:
trunk/libs/config/test/boost_no_limits_lowest.ipp
trunk/libs/config/test/no_limits_lowest_fail.cpp
trunk/libs/config/test/no_limits_lowest_pass.cpp
Text files modified:
trunk/boost/config/compiler/pathscale.hpp | 2 +-
trunk/boost/config/compiler/pgi.hpp | 2 +-
trunk/boost/config/stdlib/dinkumware.hpp | 2 +-
trunk/boost/config/stdlib/libcomo.hpp | 2 +-
trunk/boost/config/stdlib/libstdcpp3.hpp | 2 +-
trunk/boost/config/stdlib/modena.hpp | 2 +-
trunk/boost/config/stdlib/msl.hpp | 2 +-
trunk/boost/config/stdlib/roguewave.hpp | 2 +-
trunk/boost/config/stdlib/sgi.hpp | 2 +-
trunk/boost/config/stdlib/stlport.hpp | 2 +-
trunk/boost/config/stdlib/vacpp.hpp | 2 +-
trunk/boost/config/suffix.hpp | 4 ++++
trunk/libs/config/doc/html/boost_config/acknowledgements.html | 2 +-
trunk/libs/config/doc/html/boost_config/boost_macro_reference.html | 23 +++++++++++++++++++++--
trunk/libs/config/doc/html/boost_config/guidelines_for_boost_authors.html | 2 +-
trunk/libs/config/doc/html/boost_config/rationale.html | 2 +-
trunk/libs/config/doc/html/index.html | 4 ++--
trunk/libs/config/doc/macro_reference.qbk | 3 ++-
trunk/libs/config/test/all/Jamfile.v2 | 6 +++---
trunk/libs/config/test/boost_no_cxx11_numeric_limits.ipp | 4 ++--
trunk/libs/config/test/config_info.cpp | 2 +-
trunk/libs/config/test/config_test.cpp | 10 +++++-----
trunk/libs/config/test/no_cxx11_numeric_limits_fail.cpp | 10 +++++-----
trunk/libs/config/test/no_cxx11_numeric_limits_pass.cpp | 12 ++++++------
24 files changed, 65 insertions(+), 41 deletions(-)
Modified: trunk/boost/config/compiler/pathscale.hpp
==============================================================================
--- trunk/boost/config/compiler/pathscale.hpp (original)
+++ trunk/boost/config/compiler/pathscale.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -42,7 +42,7 @@
# define BOOST_NO_CXX11_RANGE_BASED_FOR
# define BOOST_NO_CXX11_RAW_LITERALS
# define BOOST_NO_CXX11_NULLPTR
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_NOEXCEPT
# define BOOST_NO_CXX11_LAMBDAS
# define BOOST_NO_CXX11_LOCAL_CLASS_TEMPLATE_PARAMETERS
Modified: trunk/boost/config/compiler/pgi.hpp
==============================================================================
--- trunk/boost/config/compiler/pgi.hpp (original)
+++ trunk/boost/config/compiler/pgi.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -79,7 +79,7 @@
#define BOOST_NO_CXX11_LOCAL_CLASS_TEMPLATE_PARAMETERS
#define BOOST_NO_CXX11_NOEXCEPT
#define BOOST_NO_CXX11_NULLPTR
-#define BOOST_NO_NUMERIC_LIMITS_LOWEST
+#define BOOST_NO_CXX11_NUMERIC_LIMITS
#define BOOST_NO_CXX11_RANGE_BASED_FOR
#define BOOST_NO_CXX11_RAW_LITERALS
#define BOOST_NO_CXX11_RVALUE_REFERENCES
Modified: trunk/boost/config/stdlib/dinkumware.hpp
==============================================================================
--- trunk/boost/config/stdlib/dinkumware.hpp (original)
+++ trunk/boost/config/stdlib/dinkumware.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -106,7 +106,7 @@
# define BOOST_NO_CXX11_HDR_TUPLE
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_FUNCTIONAL
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_SMART_PTR
#endif
Modified: trunk/boost/config/stdlib/libcomo.hpp
==============================================================================
--- trunk/boost/config/stdlib/libcomo.hpp (original)
+++ trunk/boost/config/stdlib/libcomo.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -53,7 +53,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/stdlib/libstdcpp3.hpp
==============================================================================
--- trunk/boost/config/stdlib/libstdcpp3.hpp (original)
+++ trunk/boost/config/stdlib/libstdcpp3.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -136,7 +136,7 @@
// C++0x features in GCC 4.5.0 and later
//
#if __GNUC__ < 4 || (__GNUC__ == 4 && __GNUC_MINOR__ < 5) || !defined(__GXX_EXPERIMENTAL_CXX0X__)
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_HDR_FUTURE
# define BOOST_NO_CXX11_HDR_RANDOM
#endif
Modified: trunk/boost/config/stdlib/modena.hpp
==============================================================================
--- trunk/boost/config/stdlib/modena.hpp (original)
+++ trunk/boost/config/stdlib/modena.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -42,7 +42,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/stdlib/msl.hpp
==============================================================================
--- trunk/boost/config/stdlib/msl.hpp (original)
+++ trunk/boost/config/stdlib/msl.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -66,7 +66,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/stdlib/roguewave.hpp
==============================================================================
--- trunk/boost/config/stdlib/roguewave.hpp (original)
+++ trunk/boost/config/stdlib/roguewave.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -178,7 +178,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/stdlib/sgi.hpp
==============================================================================
--- trunk/boost/config/stdlib/sgi.hpp (original)
+++ trunk/boost/config/stdlib/sgi.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -136,7 +136,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/stdlib/stlport.hpp
==============================================================================
--- trunk/boost/config/stdlib/stlport.hpp (original)
+++ trunk/boost/config/stdlib/stlport.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -226,7 +226,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/stdlib/vacpp.hpp
==============================================================================
--- trunk/boost/config/stdlib/vacpp.hpp (original)
+++ trunk/boost/config/stdlib/vacpp.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -42,7 +42,7 @@
# define BOOST_NO_CXX11_HDR_TYPEINDEX
# define BOOST_NO_CXX11_HDR_UNORDERED_MAP
# define BOOST_NO_CXX11_HDR_UNORDERED_SET
-# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+# define BOOST_NO_CXX11_NUMERIC_LIMITS
# define BOOST_NO_CXX11_ALLOCATOR
# define BOOST_NO_CXX11_ATOMIC_SMART_PTR
# define BOOST_NO_CXX11_SMART_PTR
Modified: trunk/boost/config/suffix.hpp
==============================================================================
--- trunk/boost/config/suffix.hpp (original)
+++ trunk/boost/config/suffix.hpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -847,6 +847,10 @@
#if defined(BOOST_NO_CXX11_VARIADIC_MACROS) && !defined(BOOST_NO_VARIADIC_MACROS)
# define BOOST_NO_VARIADIC_MACROS
#endif
+// Use BOOST_NO_CXX11_NUMERIC_LIMITS instead of BOOST_NO_NUMERIC_LIMITS_LOWEST
+#if defined(BOOST_NO_CXX11_NUMERIC_LIMITS) && !defined(BOOST_NO_NUMERIC_LIMITS_LOWEST)
+# define BOOST_NO_NUMERIC_LIMITS_LOWEST
+#endif
// ------------------ End of deprecated macros for 1.51 ---------------------------
Modified: trunk/libs/config/doc/html/boost_config/acknowledgements.html
==============================================================================
--- trunk/libs/config/doc/html/boost_config/acknowledgements.html (original)
+++ trunk/libs/config/doc/html/boost_config/acknowledgements.html 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/html; charset=US-ASCII">
<title>Acknowledgements</title>
<link rel="stylesheet" href="../../../../../doc/src/boostbook.css" type="text/css">
-<meta name="generator" content="DocBook XSL Stylesheets V1.76.1">
+<meta name="generator" content="DocBook XSL Stylesheets V1.75.2">
<link rel="home" href="../index.html" title="Boost.Config">
<link rel="up" href="../index.html" title="Boost.Config">
<link rel="prev" href="rationale.html" title="Rationale">
Modified: trunk/libs/config/doc/html/boost_config/boost_macro_reference.html
==============================================================================
--- trunk/libs/config/doc/html/boost_config/boost_macro_reference.html (original)
+++ trunk/libs/config/doc/html/boost_config/boost_macro_reference.html 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/html; charset=US-ASCII">
<title>Boost Macro Reference</title>
<link rel="stylesheet" href="../../../../../doc/src/boostbook.css" type="text/css">
-<meta name="generator" content="DocBook XSL Stylesheets V1.76.1">
+<meta name="generator" content="DocBook XSL Stylesheets V1.75.2">
<link rel="home" href="../index.html" title="Boost.Config">
<link rel="up" href="../index.html" title="Boost.Config">
<link rel="prev" href="../index.html" title="Boost.Config">
@@ -556,7 +556,7 @@
<tr>
<td>
<p>
- <code class="computeroutput"><span class="identifier">BOOST_NO_NUMERIC_LIMITS_LOWEST</span></code>
+ <code class="computeroutput"><span class="identifier">BOOST_NO_CXX11_NUMERIC_LIMITS</span></code>
</p>
</td>
<td>
@@ -4671,6 +4671,25 @@
<td>
</td>
</tr>
+<tr>
+<td>
+ <p>
+ <code class="computeroutput"><span class="identifier">BOOST_NO_NUMERIC_LIMITS_LOWEST</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ <code class="computeroutput"><span class="identifier">BOOST_NO_CXX11_NUMERIC_LIMITS</span></code>
+ </p>
+ </td>
+<td>
+ <p>
+ Boost 1.51
+ </p>
+ </td>
+<td>
+ </td>
+</tr>
</tbody>
</table></div>
</div>
Modified: trunk/libs/config/doc/html/boost_config/guidelines_for_boost_authors.html
==============================================================================
--- trunk/libs/config/doc/html/boost_config/guidelines_for_boost_authors.html (original)
+++ trunk/libs/config/doc/html/boost_config/guidelines_for_boost_authors.html 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/html; charset=US-ASCII">
<title>Guidelines for Boost Authors</title>
<link rel="stylesheet" href="../../../../../doc/src/boostbook.css" type="text/css">
-<meta name="generator" content="DocBook XSL Stylesheets V1.76.1">
+<meta name="generator" content="DocBook XSL Stylesheets V1.75.2">
<link rel="home" href="../index.html" title="Boost.Config">
<link rel="up" href="../index.html" title="Boost.Config">
<link rel="prev" href="boost_macro_reference.html" title="Boost Macro Reference">
Modified: trunk/libs/config/doc/html/boost_config/rationale.html
==============================================================================
--- trunk/libs/config/doc/html/boost_config/rationale.html (original)
+++ trunk/libs/config/doc/html/boost_config/rationale.html 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/html; charset=US-ASCII">
<title>Rationale</title>
<link rel="stylesheet" href="../../../../../doc/src/boostbook.css" type="text/css">
-<meta name="generator" content="DocBook XSL Stylesheets V1.76.1">
+<meta name="generator" content="DocBook XSL Stylesheets V1.75.2">
<link rel="home" href="../index.html" title="Boost.Config">
<link rel="up" href="../index.html" title="Boost.Config">
<link rel="prev" href="guidelines_for_boost_authors.html" title="Guidelines for Boost Authors">
Modified: trunk/libs/config/doc/html/index.html
==============================================================================
--- trunk/libs/config/doc/html/index.html (original)
+++ trunk/libs/config/doc/html/index.html 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/html; charset=US-ASCII">
<title>Boost.Config</title>
<link rel="stylesheet" href="../../../../doc/src/boostbook.css" type="text/css">
-<meta name="generator" content="DocBook XSL Stylesheets V1.76.1">
+<meta name="generator" content="DocBook XSL Stylesheets V1.75.2">
<link rel="home" href="index.html" title="Boost.Config">
<link rel="next" href="boost_config/boost_macro_reference.html" title="Boost Macro Reference">
</head>
@@ -951,7 +951,7 @@
</div>
</div>
<table xmlns:rev="http://www.cs.rpi.edu/~gregod/boost/tools/doc/revision" width="100%"><tr>
-<td align="left"><p><small>Last revised: July 10, 2012 at 19:03:16 GMT</small></p></td>
+<td align="left"><p><small>Last revised: July 12, 2012 at 13:53:08 GMT</small></p></td>
<td align="right"><div class="copyright-footer"></div></td>
</tr></table>
<hr>
Modified: trunk/libs/config/doc/macro_reference.qbk
==============================================================================
--- trunk/libs/config/doc/macro_reference.qbk (original)
+++ trunk/libs/config/doc/macro_reference.qbk 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -149,7 +149,7 @@
this symbol in library code; always include `<boost/limits.hpp>`, which
guarantees to provide `std::numeric_limits`.
]]
-[[`BOOST_NO_NUMERIC_LIMITS_LOWEST`][Standard library][
+[[`BOOST_NO_CXX11_NUMERIC_LIMITS`][Standard library][
Static function `numeric_limits<T>::lowest()` is not available for use.
]]
[[`BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS`][Standard library][
@@ -1045,6 +1045,7 @@
[[`BOOST_NO_UNIFIED_INITIALIZATION_SYNTAX`][`BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX`][Boost 1.51][]]
[[`BOOST_NO_VARIADIC_TEMPLATES`][`BOOST_NO_CXX11_VARIADIC_TEMPLATES`][Boost 1.51][]]
[[`BOOST_NO_VARIADIC_MACROS`][`BOOST_NO_CXX11_VARIADIC_MACROS`][Boost 1.51][]]
+[[`BOOST_NO_NUMERIC_LIMITS_LOWEST`][`BOOST_NO_CXX11_NUMERIC_LIMITS`][Boost 1.51][]]
]
[endsect]
Modified: trunk/libs/config/test/all/Jamfile.v2
==============================================================================
--- trunk/libs/config/test/all/Jamfile.v2 (original)
+++ trunk/libs/config/test/all/Jamfile.v2 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -367,9 +367,9 @@
test-suite "BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS" :
[ run ../no_limits_const_exp_pass.cpp ]
[ compile-fail ../no_limits_const_exp_fail.cpp ] ;
-test-suite "BOOST_NO_NUMERIC_LIMITS_LOWEST" :
-[ run ../no_limits_lowest_pass.cpp ]
-[ compile-fail ../no_limits_lowest_fail.cpp ] ;
+test-suite "BOOST_NO_CXX11_NUMERIC_LIMITS" :
+[ run ../no_cxx11_numeric_limits_pass.cpp ]
+[ compile-fail ../no_cxx11_numeric_limits_fail.cpp ] ;
test-suite "BOOST_NO_LONG_LONG_NUMERIC_LIMITS" :
[ run ../no_ll_limits_pass.cpp ]
[ compile-fail ../no_ll_limits_fail.cpp ] ;
Copied: trunk/libs/config/test/boost_no_cxx11_numeric_limits.ipp (from r79449, /trunk/libs/config/test/boost_no_limits_lowest.ipp)
==============================================================================
--- /trunk/libs/config/test/boost_no_limits_lowest.ipp (original)
+++ trunk/libs/config/test/boost_no_cxx11_numeric_limits.ipp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -5,13 +5,13 @@
// See http://www.boost.org/libs/config for most recent version.
-// MACRO: BOOST_NO_NUMERIC_LIMITS_LOWEST
+// MACRO: BOOST_NO_CXX11_NUMERIC_LIMITS
// TITLE: static function lowest() in numeric_limits class <limits>
// DESCRIPTION: static function numeric_limits<T>::lowest() are not available for use.
#include <limits>
-namespace boost_no_numeric_limits_lowest{
+namespace boost_no_cxx11_numeric_limits{
int f()
{
Deleted: trunk/libs/config/test/boost_no_limits_lowest.ipp
==============================================================================
--- trunk/libs/config/test/boost_no_limits_lowest.ipp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
+++ (empty file)
@@ -1,31 +0,0 @@
-// (C) Copyright Vicente J. Botet Escriba 2010.
-// Use, modification and distribution are subject to the
-// Boost Software License, Version 1.0. (See accompanying file
-// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
-
-// See http://www.boost.org/libs/config for most recent version.
-
-// MACRO: BOOST_NO_NUMERIC_LIMITS_LOWEST
-// TITLE: static function lowest() in numeric_limits class <limits>
-// DESCRIPTION: static function numeric_limits<T>::lowest() are not available for use.
-
-#include <limits>
-
-namespace boost_no_numeric_limits_lowest{
-
-int f()
-{
- // this is never called, it just has to compile:
- return std::numeric_limits<int>::lowest();
-}
-
-int test()
-{
- return 0;
-}
-
-}
-
-
-
-
Modified: trunk/libs/config/test/config_info.cpp
==============================================================================
--- trunk/libs/config/test/config_info.cpp (original)
+++ trunk/libs/config/test/config_info.cpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -1061,7 +1061,7 @@
PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATE_KEYWORD);
PRINT_MACRO(BOOST_NO_MS_INT64_NUMERIC_LIMITS);
PRINT_MACRO(BOOST_NO_NESTED_FRIENDSHIP);
- PRINT_MACRO(BOOST_NO_NUMERIC_LIMITS_LOWEST);
+ PRINT_MACRO(BOOST_NO_CXX11_NUMERIC_LIMITS);
PRINT_MACRO(BOOST_NO_OPERATORS_IN_NAMESPACE);
PRINT_MACRO(BOOST_NO_PARTIAL_SPECIALIZATION_IMPLICIT_DEFAULT_ARGS);
PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_CONST);
Modified: trunk/libs/config/test/config_test.cpp
==============================================================================
--- trunk/libs/config/test/config_test.cpp (original)
+++ trunk/libs/config/test/config_test.cpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -342,10 +342,10 @@
#else
namespace boost_no_limits_compile_time_constants = empty_boost;
#endif
-#ifndef BOOST_NO_NUMERIC_LIMITS_LOWEST
-#include "boost_no_limits_lowest.ipp"
+#ifndef BOOST_NO_CXX11_NUMERIC_LIMITS
+#include "boost_no_cxx11_numeric_limits.ipp"
#else
-namespace boost_no_numeric_limits_lowest = empty_boost;
+namespace boost_no_cxx11_numeric_limits = empty_boost;
#endif
#ifndef BOOST_NO_LONG_LONG_NUMERIC_LIMITS
#include "boost_no_ll_limits.ipp"
@@ -1461,9 +1461,9 @@
std::cerr << "Failed test for BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS at: " << __FILE__ << ":" << __LINE__ << std::endl;
++error_count;
}
- if(0 != boost_no_numeric_limits_lowest::test())
+ if(0 != boost_no_cxx11_numeric_limits::test())
{
- std::cerr << "Failed test for BOOST_NO_NUMERIC_LIMITS_LOWEST at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_CXX11_NUMERIC_LIMITS at: " << __FILE__ << ":" << __LINE__ << std::endl;
++error_count;
}
if(0 != boost_no_long_long_numeric_limits::test())
Copied: trunk/libs/config/test/no_cxx11_numeric_limits_fail.cpp (from r79449, /trunk/libs/config/test/no_limits_lowest_fail.cpp)
==============================================================================
--- trunk/libs/config/test/no_limits_lowest_fail.cpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
+++ (empty file)
@@ -1,37 +0,0 @@
-// This file was automatically generated on Sat Sep 25 16:53:41 2010
-// by libs/config/tools/generate.cpp
-// Copyright John Maddock 2002-4.
-// Use, modification and distribution are subject to the
-// Boost Software License, Version 1.0. (See accompanying file
-// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
-
-// See http://www.boost.org/libs/config for the most recent version.//
-// Revision $Id: generate.cpp 49281 2008-10-11 15:40:44Z johnmaddock $
-//
-
-
-// Test file for macro BOOST_NO_NUMERIC_LIMITS_LOWEST
-// This file should not compile, if it does then
-// BOOST_NO_NUMERIC_LIMITS_LOWEST should not be defined.
-// See file boost_no_limits_lowest.ipp for details
-
-// Must not have BOOST_ASSERT_CONFIG set; it defeats
-// the objective of this file:
-#ifdef BOOST_ASSERT_CONFIG
-# undef BOOST_ASSERT_CONFIG
-#endif
-
-#include <boost/config.hpp>
-#include "test.hpp"
-
-#ifdef BOOST_NO_NUMERIC_LIMITS_LOWEST
-#include "boost_no_limits_lowest.ipp"
-#else
-#error "this file should not compile"
-#endif
-
-int main( int, char *[] )
-{
- return boost_no_numeric_limits_lowest::test();
-}
-
Deleted: trunk/libs/config/test/no_limits_lowest_pass.cpp
==============================================================================
--- trunk/libs/config/test/no_limits_lowest_pass.cpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
+++ (empty file)
@@ -1,37 +0,0 @@
-// This file was automatically generated on Sat Sep 25 16:53:41 2010
-// by libs/config/tools/generate.cpp
-// Copyright John Maddock 2002-4.
-// Use, modification and distribution are subject to the
-// Boost Software License, Version 1.0. (See accompanying file
-// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
-
-// See http://www.boost.org/libs/config for the most recent version.//
-// Revision $Id: generate.cpp 49281 2008-10-11 15:40:44Z johnmaddock $
-//
-
-
-// Test file for macro BOOST_NO_NUMERIC_LIMITS_LOWEST
-// This file should compile, if it does not then
-// BOOST_NO_NUMERIC_LIMITS_LOWEST should be defined.
-// See file boost_no_limits_lowest.ipp for details
-
-// Must not have BOOST_ASSERT_CONFIG set; it defeats
-// the objective of this file:
-#ifdef BOOST_ASSERT_CONFIG
-# undef BOOST_ASSERT_CONFIG
-#endif
-
-#include <boost/config.hpp>
-#include "test.hpp"
-
-#ifndef BOOST_NO_NUMERIC_LIMITS_LOWEST
-#include "boost_no_limits_lowest.ipp"
-#else
-namespace boost_no_numeric_limits_lowest = empty_boost;
-#endif
-
-int main( int, char *[] )
-{
- return boost_no_numeric_limits_lowest::test();
-}
-
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- /trunk/libs/config/test/no_limits_lowest_fail.cpp (original)
+++ trunk/libs/config/test/no_cxx11_numeric_limits_fail.cpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -10,9 +10,9 @@
//
// Test file for macro BOOST_NO_NUMERIC_LIMITS_LOWEST
// This file should not compile, if it does then
// BOOST_NO_NUMERIC_LIMITS_LOWEST should not be defined.
// See file boost_no_limits_lowest.ipp for details
// Must not have BOOST_ASSERT_CONFIG set; it defeats
@@ -24,14 +24,14 @@
#include <boost/config.hpp>
#include "test.hpp"
-#ifdef BOOST_NO_NUMERIC_LIMITS_LOWEST
-#include "boost_no_limits_lowest.ipp"
+#ifdef BOOST_NO_CXX11_NUMERIC_LIMITS
+#include "boost_no_cxx11_numeric_limits.ipp"
#else
#error "this file should not compile"
#endif
int main( int, char *[] )
{
- return boost_no_numeric_limits_lowest::test();
+ return boost_no_cxx11_numeric_limits::test();
}
Copied: trunk/libs/config/test/no_cxx11_numeric_limits_pass.cpp (from r79449, /trunk/libs/config/test/no_limits_lowest_pass.cpp)
==============================================================================
@@ -10,9 +10,9 @@
//
-// Test file for macro BOOST_NO_NUMERIC_LIMITS_LOWEST
+// Test file for macro BOOST_NO_CXX11_NUMERIC_LIMITS
// This file should not compile, if it does then
@@ -10,9 +10,9 @@
// This file should not compile, if it does then
-// BOOST_NO_NUMERIC_LIMITS_LOWEST should not be defined.
+// BOOST_NO_CXX11_NUMERIC_LIMITS should not be defined.
// See file boost_no_limits_lowest.ipp for details
// Must not have BOOST_ASSERT_CONFIG set; it defeats
--- /trunk/libs/config/test/no_limits_lowest_pass.cpp (original)
+++ trunk/libs/config/test/no_cxx11_numeric_limits_pass.cpp 2012-07-12 09:57:00 EDT (Thu, 12 Jul 2012)
@@ -10,9 +10,9 @@
//
// Test file for macro BOOST_NO_NUMERIC_LIMITS_LOWEST
// This file should compile, if it does not then
// BOOST_NO_NUMERIC_LIMITS_LOWEST should be defined.
// See file boost_no_limits_lowest.ipp for details
// Must not have BOOST_ASSERT_CONFIG set; it defeats
@@ -24,14 +24,14 @@
#include <boost/config.hpp>
#include "test.hpp"
-#ifndef BOOST_NO_NUMERIC_LIMITS_LOWEST
-#include "boost_no_limits_lowest.ipp"
+#ifndef BOOST_NO_CXX11_NUMERIC_LIMITS
+#include "boost_no_cxx11_numeric_limits.ipp"
#else
-namespace boost_no_numeric_limits_lowest = empty_boost;
+namespace boost_no_cxx11_numeric_limits = empty_boost;
#endif
int main( int, char *[] )
{
- return boost_no_numeric_limits_lowest::test();
+ return boost_no_cxx11_numeric_limits::test();
}
Deleted: trunk/libs/config/test/no_limits_lowest_fail.cpp
==============================================================================
@@ -10,9 +10,9 @@
//
-// Test file for macro BOOST_NO_NUMERIC_LIMITS_LOWEST
+// Test file for macro BOOST_NO_CXX11_NUMERIC_LIMITS
// This file should compile, if it does not then
@@ -10,9 +10,9 @@
// This file should compile, if it does not then
-// BOOST_NO_NUMERIC_LIMITS_LOWEST should be defined.
+// BOOST_NO_CXX11_NUMERIC_LIMITS should be defined.
// See file boost_no_limits_lowest.ipp for details
// Must not have BOOST_ASSERT_CONFIG set; it defeats